@@ -5,7 +5,9 @@ u <- c(TRUE, TRUE, FALSE, NA)
 v <- c("A", "B", "B", NA_character_)
 w <- c(0L, 1L, 2L, NA_integer_)
 x <- c(5.1, 6.2, 7.3, NA_real_)
-y <- seq.Date(from = as.Date("2011-01-01"), to = as.Date("2011-07-01"), length.out = 4)
+y <- seq.Date(from = as.Date("2011-01-01"),
+              to = as.Date("2011-07-01"),
+              length.out = 4)
 z <- factor(c("AK", "HI", "CA", "NY"))
 
 test_that("describe() produces data.frames.", {
@@ -16,10 +18,3 @@ test_that("describe() produces data.frames.", {
   expect_is(describe(y), "data.frame")
   expect_is(describe(z), "data.frame")
 })
-
-s <- 1:100
-class(s) <- "foo"
-test_that("describe() handles unknown classes appropriately.", {
-  expect_message(describe(s))
-  expect_equal(describe(s), NULL)
-})
